@@ -1,14 +1,17 @@
 def first(win)
   win.remove(win.child) if win.child 
+  bindtextdomain("dcast", localedir="./locale")
+
   table = Gtk::Table.new(2, 2, false)
-  str = "DCASTѤƤ꤬Ȥޤ\nDCASTȤȴñ˥饹ۤ뤳ȤǤޤ\n\n̲ˤֿʤפΥܥ򲡤Ʋ"
   image_show(0, 1, 0, 1, table)
-  text_show(1, 0, 400, 400, table, str)
+
+  label = Gtk::Label.new(NKF.nkf("-m0 -w", _("Thank you for using DCAST.\n\nPlease push the button of \"Next\" under the screen.")))
+  table.attach(label, 1, 2, 0, 1)
+
   $flag = "first"
   dummy = Array.new
   bottom_show(0, 2, 1, 2, win, table, dummy)
 
-  #win.set_window_position(Gtk::Window::POS_MOUSE)
   win.set_default_size(500,300)
   win.set_title("DCAST")
   win.add(table)
@@ -16,7 +19,7 @@ def first(win)
 end
 
 if __FILE__ == $0
-  require "load"
+  require 'load'
 
   Gtk.init
 
@@ -25,7 +28,7 @@ if __FILE__ == $0
     Gtk::main_quit
   }
 
-  select_eth(win)
+  first(win)
 
   Gtk.main
 end
