@@ -2,7 +2,7 @@
 require 'gtk2'
 require 'nkf'
 require "allremove-gtk"
-require "first-gtk"
+#require "first-gtk"
 require "first-select-gtk"
 require "select-eth-gtk"
 require "master-info-gtk"
@@ -14,6 +14,10 @@ require "run-gtk"
 require "common"
 require "mydialog"
 require "fstab-gtk"
+require "gettext"
+
+include GetText
+bindtextdomain("dcast", localedir="./locale")
 
 # DCAST
 require "check"
