@@ -15,12 +15,13 @@ end
 
 def select_eth(win)
   win.remove(win.child)
+  bindtextdomain("dcast", localedir="./locale")
+
   table = Gtk::Table.new(3, 2, false)
 
-  str = "饹ǻѤEthֹꤷƲ"
-  dummy = ""
+  label = Gtk::Label.new(NKF.nkf("-m0 -w", _("Select the Ethernet Number in cluster network.")))
 
-  label_show(1, 2, 0, 1, table, str, dummy)
+  table.attach(label, 1, 2, 0, 1)
   image_show(0, 1, 0, 2, table)
 
   combo = Gtk::Combo.new()
